SchemaLeafType

Struct SchemaLeafType 

pub struct SchemaLeafType<'a> { /* private fields */ }
YANG leaf(-list) type.

Implementations

Source

impl SchemaLeafType<'_>

pub fn as_raw(&self) -> *mut lysc_type

Returns a mutable raw pointer to the underlying C library representation of the leaf type.

pub fn base_type(&self) -> DataValueType

Returns the resolved base type.

pub fn typedef_name(&self) -> Option<String>

Returns the typedef name if it exists.

pub fn leafref_real_type(&self) -> Option<SchemaLeafType<'_>>

Returns the real type of the leafref, corresponding to the first non-leafref in a possible chain of leafrefs.