pub struct SchemaExtInstance<'a> { /* private fields */ }Expand description
YANG extension instance.
Implementations
Sourceimpl<'a> SchemaExtInstance<'a>
impl<'a> SchemaExtInstance<'a>
Sourcepub fn as_raw(&self) -> *mut lysc_ext_instance
pub fn as_raw(&self) -> *mut lysc_ext_instance
Returns a mutable raw pointer to the underlying C library representation of the extension instance.
Sourcepub fn new_path(
&self,
path: &str,
value: Option<&str>,
output: bool,
) -> Result<Option<DataTree<'a>>, Error>
pub fn new_path( &self, path: &str, value: Option<&str>, output: bool, ) -> Result<Option<DataTree<'a>>, Error>
Create a new node in the extension instance based on a path.
If path points to a list key and the list instance does not exist, the key value from the predicate is used and value is ignored. Also, if a leaf-list is being created and both a predicate is defined in path and value is set, the predicate is preferred.
For key-less lists and state leaf-lists, positional predicates can be used. If no preciate is used for these nodes, they are always created.
The output parameter can be used to change the behavior to ignore RPC/action input schema nodes and use only output ones.
Returns the last created node (if any).