pub struct SchemaLeafType<'a> { /* private fields */ }Expand description
YANG leaf(-list) type.
Implementations
Sourceimpl SchemaLeafType<'_>
impl SchemaLeafType<'_>
Sourcepub fn as_raw(&self) -> *mut lysc_type
pub fn as_raw(&self) -> *mut lysc_type
Returns a mutable raw pointer to the underlying C library representation of the leaf type.
Sourcepub fn base_type(&self) -> DataValueType
pub fn base_type(&self) -> DataValueType
Returns the resolved base type.
Sourcepub fn typedef_name(&self) -> Option<String>
pub fn typedef_name(&self) -> Option<String>
Returns the typedef name if it exists.
Sourcepub fn leafref_real_type(&self) -> Option<SchemaLeafType<'_>>
pub fn leafref_real_type(&self) -> Option<SchemaLeafType<'_>>
Returns the real type of the leafref, corresponding to the first non-leafref in a possible chain of leafrefs.